Sec1Der class

Inheritance

Constructors

Sec1Der(Uint8List bytes)
Sec1Der.fromECSignature(ECSignature signature)
factory

Properties

bytes Uint8List
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
hex Hex
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toECSignature() ECSignature
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Uint8List bytes) ECSignature
encode(ECSignature signature) Uint8List