Hex class

Available extensions

Constructors

Hex(String value)
Hex.fromBytes(Uint8List bytes)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() Uint8List
toSec1Der() Sec1Der

Available on Hex, provided by the DerHexExtension extension

toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(String hex) Uint8List
encode(Uint8List bytes) String